Class: Aws::RecycleBin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RecycleBin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-recyclebin/client.rb,
sig/client.rbs
Overview
An API client for RecycleBin. To construct a client, you need to configure a :region and :credentials.
client = Aws::RecycleBin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateRuleResponseSuccess, _DeleteRuleResponseSuccess, _GetRuleResponseSuccess, _ListRulesResponseSuccess, _ListTagsForResourceResponseSuccess, _LockRuleResponseSuccess, _TagResourceResponseSuccess, _UnlockRuleResponseSuccess, _UntagResourceResponseSuccess, _UpdateRuleResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a Recycle Bin retention rule.
-
#delete_rule(params = {}) ⇒ Struct
Deletes a Recycle Bin retention rule.
-
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Gets information about a Recycle Bin retention rule.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the Recycle Bin retention rules in the Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a retention rule.
-
#lock_rule(params = {}) ⇒ Types::LockRuleResponse
Locks a Region-level retention rule.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to the specified retention rule.
-
#unlock_rule(params = {}) ⇒ Types::UnlockRuleResponse
Unlocks a retention rule.
-
#untag_resource(params = {}) ⇒ Struct
Unassigns a tag from a retention rule.
-
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates an existing Recycle Bin retention rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1156 1157 1158 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1156 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1159 1160 1161 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1159 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1129 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RecycleBin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-recyclebin' context[:gem_version] = '1.57.0' Seahorse::Client::Request.new(handlers, context) end |
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a Recycle Bin retention rule. You can create two types of retention rules:
-
Tag-level retention rules - These retention rules use resource tags to identify the resources to protect. For each retention rule, you specify one or more tag key and value pairs. Resources (of the specified type) that have at least one of these tag key and value pairs are automatically retained in the Recycle Bin upon deletion. Use this type of retention rule to protect specific resources in your account based on their tags.
-
Region-level retention rules - These retention rules, by default, apply to all of the resources (of the specified type) in the Region, even if the resources are not tagged. However, you can specify exclusion tags to exclude resources that have specific tags. Use this type of retention rule to protect all resources of a specific type in a Region.
For more information, see Create Recycle Bin retention rules in the Amazon EBS User Guide.
96 |
# File 'sig/client.rbs', line 96
def create_rule: (
|
#delete_rule(params = {}) ⇒ Struct
Deletes a Recycle Bin retention rule. For more information, see Delete Recycle Bin retention rules in the Amazon Elastic Compute Cloud User Guide.
134 |
# File 'sig/client.rbs', line 134
def delete_rule: (
|
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Gets information about a Recycle Bin retention rule.
154 |
# File 'sig/client.rbs', line 154
def get_rule: (
|
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the Recycle Bin retention rules in the Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
165 |
# File 'sig/client.rbs', line 165
def list_rules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a retention rule.
190 |
# File 'sig/client.rbs', line 190
def list_tags_for_resource: (
|
#lock_rule(params = {}) ⇒ Types::LockRuleResponse
Locks a Region-level retention rule. A locked retention rule can't be modified or deleted.
209 |
# File 'sig/client.rbs', line 209
def lock_rule: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns tags to the specified retention rule.
224 |
# File 'sig/client.rbs', line 224
def tag_resource: (
|
#unlock_rule(params = {}) ⇒ Types::UnlockRuleResponse
Unlocks a retention rule. After a retention rule is unlocked, it can be modified or deleted only after the unlock delay period expires.
250 |
# File 'sig/client.rbs', line 250
def unlock_rule: (
|
#untag_resource(params = {}) ⇒ Struct
Unassigns a tag from a retention rule.
259 |
# File 'sig/client.rbs', line 259
def untag_resource: (
|
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates an existing Recycle Bin retention rule. You can update a retention rule's description, resource tags, and retention period at any time after creation. You can't update a retention rule's resource type after creation. For more information, see Update Recycle Bin retention rules in the Amazon Elastic Compute Cloud User Guide.
279 |
# File 'sig/client.rbs', line 279
def update_rule: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1149 1150 1151 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1149 def waiter_names [] end |