Class: Aws::RecycleBin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RecycleBin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-recyclebin/client.rb
Overview
An API client for RecycleBin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::RecycleBin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a Recycle Bin retention rule.
-
#delete_rule(params = {}) ⇒ Struct
Deletes a Recycle Bin retention rule.
-
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Gets information about a Recycle Bin retention rule.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the Recycle Bin retention rules in the Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a retention rule.
-
#lock_rule(params = {}) ⇒ Types::LockRuleResponse
Locks a Region-level retention rule.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to the specified retention rule.
-
#unlock_rule(params = {}) ⇒ Types::UnlockRuleResponse
Unlocks a retention rule.
-
#untag_resource(params = {}) ⇒ Struct
Unassigns a tag from a retention rule.
-
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates an existing Recycle Bin retention rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1156 1157 1158 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1156 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1159 1160 1161 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1159 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1129 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RecycleBin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-recyclebin' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a Recycle Bin retention rule. You can create two types of retention rules:
-
**Tag-level retention rules** - These retention rules use resource tags to identify the resources to protect. For each retention rule, you specify one or more tag key and value pairs. Resources (of the specified type) that have at least one of these tag key and value pairs are automatically retained in the Recycle Bin upon deletion. Use this type of retention rule to protect specific resources in your account based on their tags.
-
**Region-level retention rules** - These retention rules, by default, apply to all of the resources (of the specified type) in the Region, even if the resources are not tagged. However, you can specify exclusion tags to exclude resources that have specific tags. Use this type of retention rule to protect all resources of a specific type in a Region.
For more information, see [ Create Recycle Bin retention rules] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ebs/latest/userguide/recycle-bin.html
626 627 628 629 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 626 def create_rule(params = {}, = {}) req = build_request(:create_rule, params) req.send_request() end |
#delete_rule(params = {}) ⇒ Struct
Deletes a Recycle Bin retention rule. For more information, see [ Delete Recycle Bin retention rules] in the *Amazon Elastic Compute Cloud User Guide*.
654 655 656 657 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 654 def delete_rule(params = {}, = {}) req = build_request(:delete_rule, params) req.send_request() end |
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Gets information about a Recycle Bin retention rule.
708 709 710 711 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 708 def get_rule(params = {}, = {}) req = build_request(:get_rule, params) req.send_request() end |
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the Recycle Bin retention rules in the Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
793 794 795 796 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 793 def list_rules(params = {}, = {}) req = build_request(:list_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a retention rule.
823 824 825 826 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 823 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#lock_rule(params = {}) ⇒ Types::LockRuleResponse
Locks a Region-level retention rule. A locked retention rule can’t be modified or deleted.
<note markdown=“1”> You can’t lock tag-level retention rules, or Region-level retention rules that have exclusion tags.
</note>
890 891 892 893 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 890 def lock_rule(params = {}, = {}) req = build_request(:lock_rule, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns tags to the specified retention rule.
921 922 923 924 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 921 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#unlock_rule(params = {}) ⇒ Types::UnlockRuleResponse
Unlocks a retention rule. After a retention rule is unlocked, it can be modified or deleted only after the unlock delay period expires.
976 977 978 979 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 976 def unlock_rule(params = {}, = {}) req = build_request(:unlock_rule, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Unassigns a tag from a retention rule.
1003 1004 1005 1006 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1003 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates an existing Recycle Bin retention rule. You can update a retention rule’s description, resource tags, and retention period at any time after creation. You can’t update a retention rule’s resource type after creation. For more information, see [ Update Recycle Bin retention rules] in the *Amazon Elastic Compute Cloud User Guide*.
1120 1121 1122 1123 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1120 def update_rule(params = {}, = {}) req = build_request(:update_rule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1149 1150 1151 |
# File 'lib/aws-sdk-recyclebin/client.rb', line 1149 def waiter_names [] end |